@@ -146,7 +146,7 @@ int Filter::countDirectory(const QDir &dir, bool searchHiddenDirectory)
 
     QStringList::ConstIterator end = subDirs.constEnd();
     for (QStringList::ConstIterator filename = subDirs.constBegin(); filename != end; ++filename) {
-        if (!(*filename == QLatin1Char('.') || *filename == QLatin1String(".."))) {
+        if (!(*filename == QLatin1Char('.') || *filename == QLatin1StringView(".."))) {
             countDir += countDirectory(QDir(dir.filePath(*filename)), searchHiddenDirectory) + 1;
         }
     }
